@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[4]:
+# In[143]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
     pass
 
 
-# In[5]:
+# In[144]:
 
 
-version = '0.104'
+version = '0.105'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[6]:
+# In[145]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[7]:
+# In[146]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[8]:
+# In[147]:
 
 
 def testPrint(*args):
@@ -64,7 +64,7 @@ def testPrint(*args):
 
 # # Inspect
 
-# In[9]:
+# In[148]:
 
 
 import inspect
@@ -76,7 +76,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[10]:
+# In[149]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -84,7 +84,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[11]:
+# In[150]:
 
 
 def shell(cmd):
@@ -97,7 +97,7 @@ def shell(cmd):
     return out
 
 
-# In[12]:
+# In[151]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -119,13 +119,13 @@ def bash(cmd, lineList=True):
 
 # # Timing
 
-# In[13]:
+# In[152]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[14]:
+# In[153]:
 
 
 def timeSinceLastCall(name):
@@ -138,14 +138,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[15]:
+# In[154]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[16]:
+# In[155]:
 
 
 import time
@@ -173,7 +173,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[17]:
+# In[156]:
 
 
 requirements = []
@@ -205,7 +205,7 @@ import yaml
 
 # # Strings
 
-# In[18]:
+# In[157]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -235,7 +235,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[19]:
+# In[158]:
 
 
 def strUuid4():
@@ -246,14 +246,14 @@ def strUuid4():
     return uuid
 
 
-# In[20]:
+# In[159]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[21]:
+# In[160]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -265,7 +265,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[22]:
+# In[161]:
 
 
 if is_testing():
@@ -274,7 +274,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[23]:
+# In[162]:
 
 
 def strMd5Pickle4(obj):
@@ -284,14 +284,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[24]:
+# In[163]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[25]:
+# In[164]:
 
 
 def strMd5String(s):
@@ -300,7 +300,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[26]:
+# In[165]:
 
 
 if is_testing():
@@ -309,7 +309,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[27]:
+# In[166]:
 
 
 def mapThread(func, args, n=8):
@@ -334,14 +334,14 @@ if is_testing():
 
 # # Lists
 
-# In[28]:
+# In[167]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[29]:
+# In[168]:
 
 
 if is_testing():
@@ -350,7 +350,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[30]:
+# In[169]:
 
 
 def liSplit(a, number_of_splits):
@@ -358,7 +358,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[31]:
+# In[170]:
 
 
 if is_testing():
@@ -370,7 +370,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[32]:
+# In[171]:
 
 
 def liJoin(l):
@@ -380,14 +380,14 @@ def liJoin(l):
     return out
 
 
-# In[33]:
+# In[172]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[34]:
+# In[173]:
 
 
 def liFlatten(l):
@@ -404,7 +404,7 @@ def liFlatten(l):
         return l
 
 
-# In[35]:
+# In[174]:
 
 
 if is_testing():
@@ -414,7 +414,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[36]:
+# In[175]:
 
 
 regex_cache = {}
@@ -424,35 +424,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[37]:
+# In[176]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[38]:
+# In[177]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[39]:
+# In[178]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[40]:
+# In[179]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[41]:
+# In[180]:
 
 
 def lCsv(l, force_oneline=False):
@@ -468,21 +468,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[42]:
+# In[181]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[43]:
+# In[182]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[44]:
+# In[183]:
 
 
 if is_testing():
@@ -491,7 +491,7 @@ if is_testing():
 
 # # Text files
 
-# In[45]:
+# In[184]:
 
 
 def txtread(path):
@@ -512,7 +512,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[46]:
+# In[185]:
 
 
 if is_testing():
@@ -521,21 +521,21 @@ if is_testing():
 
 # # YAML files
 
-# In[47]:
+# In[186]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[48]:
+# In[187]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[49]:
+# In[188]:
 
 
 if is_testing():
@@ -548,7 +548,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[50]:
+# In[189]:
 
 
 regex_cache = {}
@@ -560,35 +560,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[51]:
+# In[190]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[52]:
+# In[191]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[53]:
+# In[192]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[54]:
+# In[193]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[55]:
+# In[194]:
 
 
 if is_testing():
@@ -597,7 +597,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[56]:
+# In[195]:
 
 
 import warnings
@@ -621,7 +621,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[57]:
+# In[196]:
 
 
 def gsGsToHttp(path):
@@ -631,7 +631,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[58]:
+# In[197]:
 
 
 def gsLs(path):
@@ -641,7 +641,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[59]:
+# In[198]:
 
 
 def gsExists(path):
@@ -651,7 +651,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[60]:
+# In[199]:
 
 
 def gsUploadFile(gsPath, path):
@@ -659,7 +659,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[61]:
+# In[200]:
 
 
 def gsTxtread(path):
@@ -671,7 +671,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[62]:
+# In[201]:
 
 
 def gsTxtwrite(path, s):
@@ -679,7 +679,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[63]:
+# In[202]:
 
 
 def gsImwrite(path, img):
@@ -688,7 +688,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[64]:
+# In[203]:
 
 
 def gsImread(path):
@@ -697,7 +697,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[65]:
+# In[204]:
 
 
 def gsPklWrite(path, obj):
@@ -705,7 +705,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[66]:
+# In[205]:
 
 
 def gsPklRead(path):
@@ -715,7 +715,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[67]:
+# In[206]:
 
 
 def pklwrite(path, obj):
@@ -728,7 +728,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[68]:
+# In[207]:
 
 
 def pklread(path):
@@ -739,7 +739,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[69]:
+# In[208]:
 
 
 if is_testing():
@@ -752,7 +752,7 @@ if is_testing():
 
 # # Images
 
-# In[70]:
+# In[209]:
 
 
 def _imreadSsh(path):
@@ -819,7 +819,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[71]:
+# In[210]:
 
 
 def imscaleNN(img, s):
@@ -831,7 +831,7 @@ def imscaleBic(img, s):
 
 
 
-# In[72]:
+# In[211]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -846,14 +846,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[73]:
+# In[212]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[74]:
+# In[213]:
 
 
 if is_testing():
@@ -861,7 +861,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[75]:
+# In[214]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -900,7 +900,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[76]:
+# In[215]:
 
 
 def imDecodeBytes(imBytes):
@@ -911,7 +911,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[77]:
+# In[216]:
 
 
 #if is_testing():
@@ -919,14 +919,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[78]:
+# In[217]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[79]:
+# In[218]:
 
 
 if is_testing():
@@ -945,7 +945,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[80]:
+# In[219]:
 
 
 def imRepeat(img, height, width):
@@ -959,7 +959,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[81]:
+# In[220]:
 
 
 if is_testing():
@@ -967,33 +967,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[82]:
+# In[221]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[83]:
+# In[222]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[84]:
+# In[223]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[85]:
+# In[224]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[86]:
+# In[225]:
 
 
 def imAddNoiseGauss(img, std):
@@ -1005,7 +1005,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[87]:
+# In[226]:
 
 
 if is_testing():
@@ -1013,7 +1013,7 @@ if is_testing():
     imshow('/tmp/img.jpg')
 
 
-# In[88]:
+# In[227]:
 
 
 def imJpgDegradation(img, quality):
@@ -1026,7 +1026,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[89]:
+# In[228]:
 
 
 def imCropCenter(img, size):
@@ -1041,35 +1041,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[90]:
+# In[229]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[91]:
+# In[230]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[92]:
+# In[231]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[93]:
+# In[232]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[94]:
+# In[233]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1092,7 +1092,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[95]:
+# In[234]:
 
 
 #if is_testing(): 
@@ -1102,7 +1102,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[96]:
+# In[235]:
 
 
 def draw_rect(img, h_beg, h_end, w_beg, w_end, line_width, color=(0, 0, 0)):
@@ -1168,7 +1168,8 @@ def imCropRandomSeed(img, sizes, idx, crop_idx, use_crop=True, use_minimap=False
             h_beg, h_end = get_beg_end(h_start, sizes[0], h_new, h)
             w_beg, w_end = get_beg_end(w_start, sizes[1], w_new, w)
             img = img[h_beg:h_end, w_beg:w_end]
-            minimap = cv2.resize(img, (sizes[0] * scale, sizes[1] * scale))
+            cv2Sizes = list(reversed(sizes))
+            minimap = cv2.resize(img, (cv2Sizes[0] * scale, cv2Sizes[1] * scale))
         else:
             h_new = sizes[0] * scale
             w_new = int(round(h_new * w / h))
@@ -1182,15 +1183,17 @@ def imCropRandomSeed(img, sizes, idx, crop_idx, use_crop=True, use_minimap=False
         return crop
 
 
-# In[97]:
+# In[236]:
 
 
 if is_testing():
-    img = imscaleNN(imNewNoise(10, 20), 10)
-    imshow(imCropRandomSeed(img, (20, 20), idx=0, crop_idx=0, use_crop=True, use_minimap=True), scale=3)
+    img = imscaleNN(imNewNoise(20, 40), 10)
+    imshow(imCropRandomSeed(img, (10, 20), idx=0, crop_idx=0, use_crop=True, use_minimap=True, minimap_region=3), scale=3)
+    imshow(imCropRandomSeed(img, (10, 20), idx=0, crop_idx=0, use_crop=False, use_minimap=True, minimap_region=3), scale=3)
+    imshow(imCropRandomSeed(img, (10, 20), idx=0, crop_idx=0, use_crop=True, use_minimap=False), scale=3)
 
 
-# In[98]:
+# In[237]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
@@ -1234,7 +1237,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
     return out
 
 
-# In[99]:
+# In[238]:
 
 
 if is_testing():
@@ -1242,7 +1245,7 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[100]:
+# In[239]:
 
 
 if is_testing():
@@ -1256,7 +1259,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1, n_rows=2))
 
 
-# In[101]:
+# In[240]:
 
 
 #if is_testing():
@@ -1264,7 +1267,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[102]:
+# In[241]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1301,7 +1304,7 @@ if is_testing():
 
 # # Video
 
-# In[103]:
+# In[242]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1321,13 +1324,13 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
-# In[104]:
+# In[243]:
 
 
 #ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
 
 
-# In[105]:
+# In[244]:
 
 
 def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
@@ -1347,7 +1350,7 @@ if is_testing():
 
 # # pytorch
 
-# In[106]:
+# In[245]:
 
 
 def ptT(img_np_uint8):
@@ -1364,7 +1367,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[107]:
+# In[246]:
 
 
 if is_testing():
@@ -1376,7 +1379,7 @@ if is_testing():
 
 # # Files
 
-# In[108]:
+# In[247]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1397,7 +1400,7 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[109]:
+# In[248]:
 
 
 import os
@@ -1420,7 +1423,7 @@ if is_testing():
     print(pexpanduser('~/tmp/file.txt'))
 
 
-# In[110]:
+# In[249]:
 
 
 if is_testing():
@@ -1449,7 +1452,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[111]:
+# In[250]:
 
 
 def fiRemove(path):
@@ -1477,7 +1480,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[112]:
+# In[251]:
 
 
 if is_testing():
@@ -1509,7 +1512,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[113]:
+# In[252]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1524,7 +1527,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[114]:
+# In[253]:
 
 
 def fiJoin(*args):
@@ -1536,7 +1539,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[115]:
+# In[254]:
 
 
 def jnSettings():
@@ -1547,7 +1550,7 @@ if is_testing():
     jnSettings()
 
 
-# In[116]:
+# In[255]:
 
 
 def jnNbFullWidth():
@@ -1561,7 +1564,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[117]:
+# In[256]:
 
 
 def jnImageRenderingPixelated():
@@ -1573,7 +1576,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[118]:
+# In[257]:
 
 
 def jnDefault():
@@ -1591,7 +1594,7 @@ if is_testing():
 
 
 
-# In[119]:
+# In[258]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1604,7 +1607,7 @@ if is_testing():
     
 
 
-# In[120]:
+# In[259]:
 
 
 def jnImgToHtmlB64(img):
@@ -1639,7 +1642,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[121]:
+# In[260]:
 
 
 if is_testing():
@@ -1647,7 +1650,7 @@ if is_testing():
    
 
 
-# In[122]:
+# In[261]:
 
 
 if is_testing():
@@ -1657,7 +1660,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[123]:
+# In[262]:
 
 
 
@@ -1665,7 +1668,7 @@ if is_testing():
    jnImageRow(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)])
 
 
-# In[124]:
+# In[263]:
 
 
 #def dfDisplayWithImgs(df):
@@ -1681,7 +1684,7 @@ if is_testing():
 
 # # GIT
 
-# In[125]:
+# In[264]:
 
 
 def gitGetHash():
@@ -1691,7 +1694,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[126]:
+# In[265]:
 
 
 def gitGetBranch():
@@ -1701,7 +1704,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[127]:
+# In[266]:
 
 
 def gitGetMessage():
@@ -1711,7 +1714,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[128]:
+# In[267]:
 
 
 def gitGetAllFiles():
@@ -1721,7 +1724,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[129]:
+# In[268]:
 
 
 def gitListByTime(path=None):
@@ -1737,7 +1740,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[130]:
+# In[269]:
 
 
 def gitTime(path):
@@ -1748,7 +1751,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[131]:
+# In[270]:
 
 
 def gitTimeRaw(path):
@@ -1759,7 +1762,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[132]:
+# In[271]:
 
 
 def shellSortDirsBySize():
@@ -1771,14 +1774,14 @@ if is_testing():
 
 # # Package Files
 
-# In[133]:
+# In[272]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[134]:
+# In[273]:
 
 
 def shell(cmd):
@@ -1786,7 +1789,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[135]:
+# In[274]:
 
 
 if is_testing():
@@ -1818,7 +1821,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[136]:
+# In[275]:
 
 
 if is_testing():
@@ -1828,7 +1831,7 @@ description-file = README.md
 """
 
 
-# In[137]:
+# In[276]:
 
 
 if is_testing():
@@ -1851,14 +1854,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[138]:
+# In[277]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[ ]:
+# In[281]:
 
 
 if is_testing():
@@ -1869,7 +1872,7 @@ if is_testing():
     print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[ ]:
+# In[282]:
 
 
 if is_testing():
@@ -1880,7 +1883,7 @@ lx/__init__.py
 """
 
 
-# In[ ]:
+# In[283]:
 
 
 if is_testing():
